==> zio-aws-iot1clickdevices_2.13-5.17.125.1-sources.jar: zio/aws/iot1clickdevices/model/DescribeDeviceRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DescribeDeviceRequest(deviceId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.DescribeDeviceRequest = {
    import DescribeDeviceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.DescribeDeviceRequest
      .builder()
      .deviceId(__string.unwrap(deviceId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.DescribeDeviceRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.DescribeDeviceRequest.wrap(buildAwsValue())
}
object DescribeDeviceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.DescribeDeviceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.DescribeDeviceRequest =
      zio.aws.iot1clickdevices.model.DescribeDeviceRequest(deviceId)
    def deviceId: __string
    def getDeviceId: ZIO[Any, Nothing, __string] = ZIO.succeed(deviceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.DescribeDeviceRequest
  ) extends zio.aws.iot1clickdevices.model.DescribeDeviceRequest.ReadOnly {
    override val deviceId: __string =
      zio.aws.iot1clickdevices.model.primitives.__string(impl.deviceId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.DescribeDeviceRequest
  ): zio.aws.iot1clickdevices.model.DescribeDeviceRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iot1clickdevices_2.13-5.17.130.8-sources.jar: zio/aws/iot1clickdevices/model/DescribeDeviceRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DescribeDeviceRequest(deviceId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.DescribeDeviceRequest = {
    import DescribeDeviceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.DescribeDeviceRequest
      .builder()
      .deviceId(deviceId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.DescribeDeviceRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.DescribeDeviceRequest.wrap(buildAwsValue())
}
object DescribeDeviceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.DescribeDeviceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.DescribeDeviceRequest =
      zio.aws.iot1clickdevices.model.DescribeDeviceRequest(deviceId)
    def deviceId: __string
    def getDeviceId: ZIO[Any, Nothing, __string] = ZIO.succeed(deviceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.DescribeDeviceRequest
  ) extends zio.aws.iot1clickdevices.model.DescribeDeviceRequest.ReadOnly {
    override val deviceId: __string = impl.deviceId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.DescribeDeviceRequest
  ): zio.aws.iot1clickdevices.model.DescribeDeviceRequest.ReadOnly =
    new Wrapper(impl)
}
